@@ -6,19 +6,18 @@
  *  linux@codehelp.co.uk
  ********************************************************************/
 /*
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    This package is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -106,6 +105,16 @@ on_open_deb (GtkMenuItem * menuitem, gpointer user_data)
 	}
 }
 
+void
+on_close_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	DVContents *deb;
+
+	deb = (DVContents*) lookup_widget 
+		(GTK_WIDGET(menuitem), DVCONTENTS);
+	gtk_widget_destroy (dv_get_parent(deb));
+}
+
 void
 on_quit_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
