@@ -6,19 +6,18 @@
  *  linux@codehelp.co.uk
  *******************************************************************/
 /*
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    This package is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -145,7 +144,7 @@ create_groups (GKeyFile * kf, const gchar * keyfile)
 
 	/* png */
 	g_key_file_set_string (kf, "PNG", DVKEYGLOB, "*.png");
-	g_key_file_set_string (kf, "PNG", DVKEYPROG, "qiv");
+	g_key_file_set_string (kf, "PNG", DVKEYPROG, "eog");
 	g_key_file_set_boolean (kf, "PNG", DVKEYTERM, FALSE);
 	g_key_file_set_boolean (kf, "PNG", DVBINARY, TRUE);
 	g_key_file_set_string (kf, "PNG", DVSUFFIX, "png");
